=========
irholiday
=========


.. image:: https://img.shields.io/pypi/v/irholiday.svg
        :target: https://pypi.python.org/pypi/irholiday

.. image:: https://img.shields.io/travis/hadi-gharibi/irholiday.svg
        :target: https://travis-ci.org/hadi-gharibi/irholiday

.. image:: https://readthedocs.org/projects/irholiday/badge/?version=latest
        :target: https://irholiday.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Pandas Datafarme data from time.ir


* Free software: MIT license
* Documentation: https://irholiday.readthedocs.io.


Features
--------

* TODO

